---
title: >
 title goes here, leading space must be there.
date: _date_time_now_
type: post
slug: _post_slug_
tags: tag1, tag2, tag3
attached:
---

Start writing your post here. Use HTML, or markdown depending on your preference.
